import React, { useState } from 'react';
import { X, ArrowLeft, ArrowRight } from 'lucide-react';
import BasicDetailsStep from './BasicDetailsStep';
import LocationDetailsStep from './LocationDetailsStep';
import LandDetailsStep from './LandDetailsStep';
import AddAmenitiesPrice from './AddAmenitiesPrice';
import UploadPage from './UploadPage';
import axios from '@/services/APIservices';

const PropertyWizardModal = ({ isOpen, onClose }) => {
  const [activeStep, setActiveStep] = useState(1);
  const [isSubmitting, setIsSubmitting] = useState(false);
  const [error, setError] = useState(null);

  const [mainFile, setMainFile] = useState(null);

  // States for form data
  const [intent, setIntent] = useState('Sell');
  const [propertyType, setPropertyType] = useState('');
  const [sizeUnit, setSizeUnit] = useState('SQ Yard');
  const [size, setSize] = useState('');
  const [length, setLength] = useState('');
  const [breadth, setBreadth] = useState('');
  const [roadTouch, setRoadTouch] = useState('');
  const [plotFacing, setPlotFacing] = useState('');
  const [distanceFromAirport, setDistanceFromAirport] = useState('');
  const [distanceFromRailway, setDistanceFromRailway] = useState('');
  const [distanceFromBusStand, setDistanceFromBusStand] = useState('');
  const [distanceFromHospital, setDistanceFromHospital] = useState('');
  const [distanceFromSchool, setDistanceFromSchool] = useState('');
  const [city, setCity] = useState('');
  const [locality, setLocality] = useState('');
  const [subLocality, setSubLocality] = useState('');
  const [detailedAddress, setDetailedAddress] = useState('');
  const [expectedPrice, setExpectedPrice] = useState('');
  const [priceUnit, setPriceUnit] = useState('');
  const [photos, setPhotos] = useState([]);
  const [youTubeLink, setYouTubeLink] = useState('');
  const [droneViewLink, setDroneViewLink] = useState('');

  const [basicRequirements, setBasicRequirements] = useState({
    water: false,
    electricity: false,
    roadAccess: false,
    boundaryWall: false,
    gatedCommunity: false
  });

  const [submittedData, setSubmittedData] = useState(null);

  if (!isOpen) return null;

  const steps = [
    { number: 1, title: 'Basic & Size Details' },
    { number: 2, title: 'Location Details' },
    { number: 3, title: 'Land Details' },
    { number: 4, title: 'Amenities' },
    { number: 5, title: 'Video And Photo' },
  ];

  const handleNext = () => {
    setActiveStep((prev) => Math.min(prev + 1, steps.length));
  };

  const handlePrevious = () => {
    setActiveStep((prev) => Math.max(prev - 1, 1));
  };

  const handlePostAsAdmin = async () => {
    setIsSubmitting(true);
    setError(null);

    try {
      // Create FormData instance
      const formData = new FormData();

      // Basic property details
      formData.append('intent', intent);
      formData.append('propertyType', propertyType);
      formData.append('sizeUnit', sizeUnit);
      formData.append('size', size);
      formData.append('length', length);
      formData.append('breadth', breadth);
      formData.append('roadTouch', roadTouch);
      formData.append('plotFacing', plotFacing);

      // Location distances
      formData.append('distanceFromAirport', distanceFromAirport);
      formData.append('distanceFromRailway', distanceFromRailway);
      formData.append('distanceFromBusStand', distanceFromBusStand);
      formData.append('distanceFromHospital', distanceFromHospital);
      formData.append('distanceFromSchool', distanceFromSchool);

      // Address details
      formData.append('city', city);
      formData.append('locality', locality);
      formData.append('subLocality', subLocality);
      formData.append('detailedAddress', detailedAddress);

      // Price details
      formData.append('expectedPrice', expectedPrice);
      formData.append('priceUnit', priceUnit);

      // Basic requirements as JSON string
      formData.append('basicRequirements', JSON.stringify(basicRequirements));

      // Links
      formData.append('youTubeLink', youTubeLink);
      formData.append('droneViewLink', droneViewLink);

      // Main file
      if (mainFile) {
        formData.append('mainFile', mainFile);
      }

      // Photos
      photos.forEach((photo, index) => {
        formData.append(`photos[${index}]`, photo);
      });

      // Send request directly to Laravel API
      const response = await axios.post('api/admin-post-properties', formData, {
        headers: {
          'Content-Type': 'multipart/form-data',
        },
        withCredentials: true // Important for CSRF protection
      });

      // Store the submitted data in state
      setSubmittedData(response.data);
      console.log('Property posted successfully:', response.data);
      
      // Close the modal after successful submission
      onClose();
      window.location.reload();
    } catch (error) {  
      console.error('Error posting property:', error);
      setError(error.response?.data?.message || 'Failed to post property. Please try again.');
    } finally {
      setIsSubmitting(false);
    }
  };

  const renderStepContent = () => {
    switch (activeStep) {
      case 1:
        return (
          <BasicDetailsStep
            intent={intent}
            setIntent={setIntent}
            propertyType={propertyType}
            setPropertyType={setPropertyType}
            sizeUnit={sizeUnit}
            setSizeUnit={setSizeUnit}
            size={size}
            setSize={setSize}
            length={length}
            setLength={setLength}
            breadth={breadth}
            setBreadth={setBreadth}
          />
        );
      case 2:
        return (
          <LocationDetailsStep
            roadTouch={roadTouch}
            setRoadTouch={setRoadTouch}
            plotFacing={plotFacing}
            setPlotFacing={setPlotFacing}
            distanceFromAirport={distanceFromAirport}
            setDistanceFromAirport={setDistanceFromAirport}
            distanceFromRailway={distanceFromRailway}
            setDistanceFromRailway={setDistanceFromRailway}
            distanceFromBusStand={distanceFromBusStand}
            setDistanceFromBusStand={setDistanceFromBusStand}
            distanceFromHospital={distanceFromHospital}
            setDistanceFromHospital={setDistanceFromHospital}
            distanceFromSchool={distanceFromSchool}
            setDistanceFromSchool={setDistanceFromSchool}
          />
        );
      case 3:
        return (
          <LandDetailsStep
            city={city}
            setCity={setCity}
            locality={locality}
            setLocality={setLocality}
            subLocality={subLocality}
            setSubLocality={setSubLocality}
            detailedAddress={detailedAddress}
            setDetailedAddress={setDetailedAddress}
          />
        );
      case 4:
        return (
          <AddAmenitiesPrice
            expectedPrice={expectedPrice}
            setExpectedPrice={setExpectedPrice}
            priceUnit={priceUnit}
            setPriceUnit={setPriceUnit}
            basicRequirements={basicRequirements}
            setBasicRequirements={setBasicRequirements}
          />
        );
      case 5:
        return (
          <UploadPage
            photos={photos}
            setPhotos={setPhotos}
            youTubeLink={youTubeLink}
            setYouTubeLink={setYouTubeLink}
            droneViewLink={droneViewLink}
            setDroneViewLink={setDroneViewLink}
            mainFile={mainFile}
            setMainFile={setMainFile}
          />
        );
      default:
        return null;
    }
  };

  return (
    <div className="fixed inset-0 z-50 flex items-start justify-center overflow-y-auto overflow-x-hidden bg-black bg-opacity-50 p-3 sm:p-4">
      <div className="relative mt-8 flex w-full max-w-5xl gap-6 sm:mt-10 md:mt-20">
        {/* Left Sidebar for Desktop */}
        <div className="hidden w-56 rounded-lg bg-gray-100 p-4 md:block md:p-6">
          <div className="space-y-4">
            {steps.map((step) => (
              <div key={step.number} className="flex flex-col">
                <div className="flex items-center gap-3">
                  <div 
                    className={`h-4 w-4 rounded-full ${
                      activeStep >= step.number ? 'bg-purple-600' : 'bg-gray-300'
                    }`} 
                  />
                  <span className="font-medium">{step.title}</span>
                </div>
                <div className="ml-[7px] mt-1 border-l border-gray-300 pl-4 text-sm text-gray-500">
                  Step {step.number}
                </div>
              </div>
            ))}
          </div>
        </div>

        {/* Progress indicator for Mobile */}
        <div className="fixed left-0 right-0 top-0 z-50 bg-white p-4 shadow-md md:hidden">
          <div className="flex items-center justify-between">
            <span className="text-sm font-medium">Step {activeStep} of {steps.length}</span>
            <div className="mx-4 flex h-2 flex-1 overflow-hidden rounded-full bg-gray-200">
              <div
                className="bg-purple-600 transition-all duration-300 ease-in-out"
                style={{ width: `${(activeStep / steps.length) * 100}%` }}
              />
            </div>
            <button 
              onClick={onClose} 
              className="text-gray-500 hover:text-gray-700"
              disabled={isSubmitting}
            >
              <X size={20} />
            </button>
          </div>
        </div>

        {/* Main Content */}
        <div className="relative w-full rounded-lg bg-white p-4 shadow-xl sm:p-6 md:p-8">
          <button 
            onClick={onClose} 
            className="absolute right-4 top-4 text-gray-500 hover:text-gray-700"
            disabled={isSubmitting}
          >
            <X size={24} />
          </button>

          <div className="mb-6 mt-12 sm:mb-8 md:mt-0">
            {renderStepContent()}
          </div>

          {error && (
            <div className="mb-4 rounded-lg bg-red-50 p-4 text-sm text-red-600">
              {error}
            </div>
          )}

          <div className="flex items-center justify-end gap-3 sm:gap-4">
            {activeStep > 1 && (
              <button
                onClick={handlePrevious}
                className="flex items-center gap-2 rounded-lg border border-gray-300 px-4 py-2 text-sm font-medium text-gray-700 hover:bg-gray-50 sm:px-6 sm:py-2.5"
                disabled={isSubmitting}
              >
                <ArrowLeft size={16} />
                Previous
              </button>
            )}
            <button
              onClick={activeStep === steps.length ? handlePostAsAdmin : handleNext}
              className="flex items-center gap-2 rounded-lg bg-purple-600 px-4 py-2 text-sm font-medium text-white hover:bg-opacity-90 sm:px-6 sm:py-2.5"
              disabled={isSubmitting}
            >
              {activeStep === steps.length ? (
                isSubmitting ? 'Posting...' : 'Post as Admin'
              ) : (
                <>
                  Next
                  <ArrowRight size={16} />
                </>
              )}
            </button>
          </div>

          {/* Display Submitted Data */}
          {submittedData && (
            <div className="mt-8 rounded-lg bg-gray-50 p-4 sm:p-6">
              <h3 className="text-lg font-medium">Submitted Property Data:</h3>
              <pre className="mt-4 overflow-x-auto rounded-lg bg-gray-100 p-4 text-sm text-gray-700">
                {JSON.stringify(submittedData, null, 2)}
              </pre>
            </div>
          )}
        </div>
      </div>
    </div>
  );
};

export default PropertyWizardModal;